@@ -4,22 +4,19 @@
 #![forbid(missing_crate_level_docs)]
 #![doc = include_str ! ("../readme.md")]
 
-extern crate core;
-
 mod builder;
 mod systems;
 mod traits;
-
 pub use self::{
     builder::TailwindBuilder,
     systems::{
         breakpoints::{BreakPoint, BreakPointSystem},
         colors::{Palette, PaletteSystem},
         fonts::FontSystem,
-        layouts::{TailwindAspect, TailwindBreak},
+        layouts::{TailWindZIndex, TailwindAspect, TailwindBreak},
         preflight::PreflightSystem,
         sizes::{TailwindMaxWidth, TailwindMinWidth, TailwindWidth},
-        TailwindObject,
+        TailwindObject, TailwindParsed,
     },
     traits::TailwindInstance,
 };
