@@ -1,5 +1,4 @@
 use super::*;
-use std::fmt::{format, Write};
 
 impl TailwindInstance for TailwindAspect {
     fn id(&self) -> String {
@@ -26,3 +25,20 @@ impl TailwindInstance for TailwindBreak {
         }
     }
 }
+
+impl TailwindInstance for TailWindZIndex {
+    fn id(&self) -> String {
+        match self {
+            Self::Positive(n) => format!("z-{}", n),
+            Self::Negative(n) => format!("-z-{}", n),
+            Self::Auto => format!("z-auto"),
+        }
+    }
+    fn attributes(&self) -> Vec<String> {
+        match self {
+            Self::Positive(n) => vec![format!("z-index: {};", n)],
+            Self::Negative(n) => vec![format!("z-index: -{};", n)],
+            Self::Auto => vec![format!("z-index: auto;")],
+        }
+    }
+}
