@@ -33,3 +33,11 @@ pub enum TailwindBreak {
     /// https://tailwindcss.com/docs/break-inside
     Inside(&'static str),
 }
+
+#[doc = include_str!("z-index.md")]
+#[derive(Copy, Clone, Debug)]
+pub enum TailWindZIndex {
+    Auto,
+    Positive(usize),
+    Negative(usize),
+}
